Controls a running structured streaming query.
Mirrors PySpark's StreamingQuery with methods for monitoring
and controlling the query lifecycle.
Examples
{:ok, query} = writer |> SparkEx.StreamWriter.start()
{:ok, true} = SparkEx.StreamingQuery.is_active?(query)
:ok = SparkEx.StreamingQuery.stop(query)
Summary
Functions
Waits for the termination of the query.
Returns exception information if the query has terminated with an error.
Returns the query plan as a string.
Returns the streaming query ID.
Returns whether the streaming query is currently active.
Returns the most recent progress report as a JSON string, or nil.
Returns the streaming query name.
Blocks until all available data in the source has been processed.
Returns a list of recent progress reports as JSON strings.
Returns the streaming query run ID.
Returns the current status of the streaming query.
Stops the streaming query.
Types
@type t() :: %SparkEx.StreamingQuery{ name: String.t() | nil, query_id: String.t(), run_id: String.t(), session: GenServer.server() }
Functions
Waits for the termination of the query.
Options
:timeout— timeout in milliseconds (default: no timeout)
Returns exception information if the query has terminated with an error.
Returns the query plan as a string.
Options
:extended— whether to include extended details (default: false)
Returns the streaming query ID.
Returns whether the streaming query is currently active.
Returns the most recent progress report as a JSON string, or nil.
Returns the streaming query name.
Blocks until all available data in the source has been processed.
Returns a list of recent progress reports as JSON strings.
Returns the streaming query run ID.
Returns the current status of the streaming query.
Stops the streaming query.